@@ -1,8 +1,7 @@
-import logging
 from datetime import datetime
-from typing import TYPE_CHECKING, Any, Set, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Iterable, Set, Dict, List, Optional, Union
 
-from naff.client.const import MISSING, logger_name, Absent
+from naff.client.const import MISSING, logger, Absent
 from naff.client.errors import HTTPException, TooManyChanges
 from naff.client.mixins.send import SendMixin
 from naff.client.utils.attr_utils import define, field, docs
@@ -30,8 +29,6 @@ if TYPE_CHECKING:
 
 __all__ = ("BaseUser", "User", "NaffUser", "Member")
 
-log = logging.getLogger(logger_name)
-
 
 class _SendDMMixin(SendMixin):
     id: "Snowflake_Type"
@@ -78,6 +75,11 @@ class BaseUser(DiscordObject, _SendDMMixin):
         """The users display name, will return nickname if one is set, otherwise will return username."""
         return self.username  # for duck-typing compatibility with Member
 
+    @property
+    def display_avatar(self) -> "Asset":
+        """The users displayed avatar, will return `guild_avatar` if one is set, otherwise will return user avatar."""
+        return self.avatar
+
     async def fetch_dm(self) -> "DM":
         """Fetch the DM channel associated with this user."""
         return await self._client.cache.fetch_dm_channel(self.id)  # noqa
@@ -132,6 +134,9 @@ class User(BaseUser):
         if "banner" in data:
             data["banner"] = Asset.from_path_hash(client, f"banners/{data['id']}/{{}}", data["banner"])
 
+        if data.get("premium_type", None) is None:
+            data["premium_type"] = 0
+
         return data
 
     @property
@@ -266,7 +271,9 @@ class Member(DiscordObject, _SendDMMixin):
                     client, f"guilds/{data['guild_id']}/users/{data['id']}/avatars/{{}}", data.pop("avatar", None)
                 )
             except Exception as e:
-                log.warning(f"[DEBUG NEEDED - REPORT THIS] Incomplete dictionary has been passed to member object: {e}")
+                logger.warning(
+                    f"[DEBUG NEEDED - REPORT THIS] Incomplete dictionary has been passed to member object: {e}"
+                )
                 raise
 
         data["role_ids"] = data.pop("roles", [])
@@ -462,6 +469,18 @@ class Member(DiscordObject, _SendDMMixin):
         await self._client.http.add_guild_member_role(self._guild_id, self.id, role, reason=reason)
         self._role_ids.append(role)
 
+    async def add_roles(self, roles: Iterable[Union[Snowflake_Type, Role]], reason: Absent[str] = MISSING) -> None:
+        """
+        Atomically add multiple roles to this member.
+
+        Args:
+            roles: The roles to add
+            reason: The reason for adding the roles
+
+        """
+        new_roles = set(self._role_ids) | {to_snowflake(r) for r in roles}
+        await self.edit(roles=new_roles, reason=reason)
+
     async def remove_role(self, role: Union[Snowflake_Type, Role], reason: Absent[str] = MISSING) -> None:
         """
         Remove a role from this user.
@@ -479,6 +498,18 @@ class Member(DiscordObject, _SendDMMixin):
         except ValueError:
             pass
 
+    async def remove_roles(self, roles: Iterable[Union[Snowflake_Type, Role]], reason: Absent[str] = MISSING) -> None:
+        """
+        Atomically remove multiple roles from this member.
+
+        Args:
+            roles: The roles to remove
+            reason: The reason for removing the roles
+
+        """
+        new_roles = set(self._role_ids) - {to_snowflake(r) for r in roles}
+        await self.edit(roles=new_roles, reason=reason)
+
     def has_role(self, *roles: Union[Snowflake_Type, Role]) -> bool:
         """
         Checks if the user has the given role(s).
@@ -528,7 +559,7 @@ class Member(DiscordObject, _SendDMMixin):
         self,
         *,
         nickname: Absent[str] = MISSING,
-        roles: Absent[list["Snowflake_Type"]] = MISSING,
+        roles: Absent[Iterable["Snowflake_Type"]] = MISSING,
         mute: Absent[bool] = MISSING,
         deaf: Absent[bool] = MISSING,
         channel_id: Absent["Snowflake_Type"] = MISSING,
