@@ -1,6 +1,5 @@
 import asyncio
 import inspect
-import logging
 import re
 import typing
 from enum import IntEnum
@@ -16,7 +15,7 @@ from naff.client.const import (
     SLASH_CMD_MAX_OPTIONS,
     SLASH_CMD_MAX_DESC_LENGTH,
     MISSING,
-    logger_name,
+    logger,
     Absent,
 )
 from naff.client.mixins.serialization import DictSerializationMixin
@@ -61,8 +60,6 @@ __all__ = (
     "LocalisedDesc",
 )
 
-log = logging.getLogger(logger_name)
-
 
 def name_validator(_: Any, attr: Attribute, value: str) -> None:
     if value:
@@ -227,7 +224,7 @@ class InteractionCommand(BaseCommand):
     async def _permission_enforcer(self, ctx: "Context") -> bool:
         """A check that enforces Discord permissions."""
         # I wish this wasn't needed, but unfortunately Discord permissions cant be trusted to actually prevent usage
-        if self.dm_permission:
+        if self.dm_permission is False:
             return ctx.guild is not None
         return True
 
@@ -295,6 +292,8 @@ class SlashCommandOption(DictSerializationMixin):
         channel_types: The channel types permitted. The option needs to be a channel
         min_value: The minimum value permitted. The option needs to be an integer or float
         max_value: The maximum value permitted. The option needs to be an integer or float
+        min_length: The minimum length of text a user can input. The option needs to be a string
+        max_length: The maximum length of text a user can input. The option needs to be a string
 
     """
 
@@ -307,6 +306,8 @@ class SlashCommandOption(DictSerializationMixin):
     channel_types: Optional[list[Union[ChannelTypes, int]]] = field(default=None)
     min_value: Optional[float] = field(default=None)
     max_value: Optional[float] = field(default=None)
+    min_length: Optional[int] = field(default=None)
+    max_length: Optional[int] = field(default=None)
 
     @type.validator
     def _type_validator(self, attribute: str, value: int) -> None:
@@ -355,6 +356,32 @@ class SlashCommandOption(DictSerializationMixin):
                 if self.max_value < self.min_value:
                     raise ValueError("`min_value` needs to be <= than `max_value`")
 
+    @min_length.validator
+    def _min_length_validator(self, attribute: str, value: Optional[int]) -> None:
+        if value is not None:
+            if self.type != OptionTypes.STRING:
+                raise ValueError("`min_length` can only be supplied with string options")
+
+            if self.max_length is not None and self.min_length is not None:
+                if self.max_length < self.min_length:
+                    raise ValueError("`min_length` needs to be <= than `max_length`")
+
+            if self.min_length < 0:
+                raise ValueError("`min_length` needs to be >= 0")
+
+    @max_length.validator
+    def _max_length_validator(self, attribute: str, value: Optional[int]) -> None:
+        if value is not None:
+            if self.type != OptionTypes.STRING:
+                raise ValueError("`max_length` can only be supplied with string options")
+
+            if self.min_length is not None and self.max_length is not None:
+                if self.max_length < self.min_length:
+                    raise ValueError("`min_length` needs to be <= than `max_length`")
+
+            if self.max_length < 1:
+                raise ValueError("`max_length` needs to be >= 1")
+
     def as_dict(self) -> dict:
         data = attrs.asdict(self)
         data["name"] = str(self.name)
@@ -804,6 +831,8 @@ def slash_option(
     channel_types: Optional[list[Union[ChannelTypes, int]]] = None,
     min_value: Optional[float] = None,
     max_value: Optional[float] = None,
+    min_length: Optional[int] = None,
+    max_length: Optional[int] = None,
 ) -> Any:
     r"""
     A decorator to add an option to a slash command.
@@ -817,6 +846,8 @@ def slash_option(
         channel_types: The channel types permitted. The option needs to be a channel
         min_value: The minimum value permitted. The option needs to be an integer or float
         max_value: The maximum value permitted. The option needs to be an integer or float
+        min_length: The minimum length of text a user can input. The option needs to be a string
+        max_length: The maximum length of text a user can input. The option needs to be a string
     """
 
     def wrapper(func: Coroutine) -> Coroutine:
@@ -833,6 +864,8 @@ def slash_option(
             channel_types=channel_types,
             min_value=min_value,
             max_value=max_value,
+            min_length=min_length,
+            max_length=max_length,
         )
         if not hasattr(func, "options"):
             func.options = []
@@ -958,7 +991,7 @@ def application_commands_to_dict(commands: Dict["Snowflake_Type", Dict[str, Inte
             nsfw = cmd_list[0].nsfw
 
             if not all(str(c.description) in (str(base_description), "No Description Set") for c in cmd_list):
-                log.warning(
+                logger.warning(
                     f"Conflicting descriptions found in `{cmd_list[0].name}` subcommands; `{str(base_description)}` will be used"
                 )
             if not all(c.default_member_permissions == cmd_list[0].default_member_permissions for c in cmd_list):
@@ -966,7 +999,7 @@ def application_commands_to_dict(commands: Dict["Snowflake_Type", Dict[str, Inte
             if not all(c.dm_permission == cmd_list[0].dm_permission for c in cmd_list):
                 raise ValueError(f"Conflicting `dm_permission` values found in `{cmd_list[0].name}`")
             if not all(c.nsfw == nsfw for c in cmd_list):
-                log.warning(f"Conflicting `nsfw` values found in {cmd_list[0].name} - `True` will be used")
+                logger.warning(f"Conflicting `nsfw` values found in {cmd_list[0].name} - `True` will be used")
                 nsfw = True
 
             for cmd in cmd_list:
@@ -1021,6 +1054,8 @@ def _compare_options(local_opt_list: dict, remote_opt_list: dict) -> bool:
         "name_localized": ("name_localizations", {}),
         "description_localized": ("description_localizations", {}),
         "choices": ("choices", []),
+        "max_value": ("max_value", None),
+        "min_value": ("min_value", None),
     }
 
     if local_opt_list != remote_opt_list:
